Class: Wx::Bitmap
- Inherits:
-
Object
- Object
- Wx::Bitmap
- Defined in:
- lib/wx/classes/bitmap.rb
Instance Method Summary collapse
-
#draw {|dc| ... } ⇒ Object
Accepts a block, which will be passed a device context which can be used to draw upon the Bitmap.
Instance Method Details
#draw {|dc| ... } ⇒ Object
Accepts a block, which will be passed a device context which can be used to draw upon the Bitmap
17 18 19 20 21 22 |
# File 'lib/wx/classes/bitmap.rb', line 17 def draw dc = Wx::MemoryDC.new dc.select_object(self) yield dc dc.select_object( Wx::NULL_BITMAP ) end |