Class: Wx::Object
- Inherits:
-
Object
- Object
- Wx::Object
- Defined in:
- lib/wx/classes/object.rb
Overview
The root class for most (not all) WxRuby classes
Instance Method Summary collapse
-
#to_s ⇒ Object
massage the output of inspect to show the public module name (Wx).
Instance Method Details
#to_s ⇒ Object
massage the output of inspect to show the public module name (Wx)
4 5 6 |
# File 'lib/wx/classes/object.rb', line 4 def to_s super.sub('ruby2', '') end |